@@ -297,8 +297,7 @@ class Wsdl(WsdlBase):
                     _("Video"),
                     normal=('os_install_x11_video_drv',
                             'os_install_x11_resolution_preferred',
-                            'os_install_x11_composite',
-                            'os_install_fb_resolution'),
+                            'os_install_x11_composite'),
                     expert=(
                         'cl_templates_locate',
                         'cl_dispatch_conf',
